@@ -9,7 +9,7 @@ pub enum Error {
 	#[error("episode missing")]
 	EpisodeMissing,
 	#[error("wrong media type {0} for {1}")]
-	WrongMediaType(String, String),
+	WrongMediaType(&'static str, &'static str),
 	#[error("HTTP error")]
 	HTTP(#[from] reqwest::Error),
 	#[error("CSV error")]
